moirai
======

*This project is currently in pre-alpha. It doesn't work yet. Check it out again
later.*

Moirai is a digital control platform which allows you to model and control slow plants, like water tanks and ovens.
